
# clustergrammer_widget2

[![Build Status](https://travis-ci.org/ismms-himc/clustergrammer_widget2.svg?branch=master)](https://travis-ci.org/ismms-himc/clustergrammer_widget2)
[![codecov](https://codecov.io/gh/ismms-himc/clustergrammer_widget2/branch/master/graph/badge.svg)](https://codecov.io/gh/ismms-himc/clustergrammer_widget2)

[![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/ismms-himc/clustergrammer_widget2/master?filepath=examples%2Fintroduction.ipynb)


A Custom Jupyter Widget Library

## Installation

A typical installation requires the following commands to be run:

```bash
pip install clustergrammer_widget2
jupyter nbextension enable --py [--sys-prefix|--user|--system] clustergrammer_widget2
```

Or, if you use jupyterlab:

```bash
pip install clustergrammer_widget2
jupyter labextension install @jupyter-widgets/jupyterlab-manager
```
